==> openshift-model-5.12.3-sources.jar: io/fabric8/openshift/api/model/DockerBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DockerBuildStrategyBuilder extends io.fabric8.openshift.api.model.DockerBuildStrategyFluentImpl<io.fabric8.openshift.api.model.DockerBuildStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.DockerBuildStrategy,io.fabric8.openshift.api.model.DockerBuildStrategyBuilder>{
  public DockerBuildStrategyBuilder() {
    this(false);
  }
  public DockerBuildStrategyBuilder(java.lang.Boolean validationEnabled) {
    this(new DockerBuildStrategy(), validationEnabled);
  }
  public DockerBuildStrategyBuilder(io.fabric8.openshift.api.model.DockerBuildStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public DockerBuildStrategyBuilder(io.fabric8.openshift.api.model.DockerBuildStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DockerBuildStrategy(), validationEnabled);
  }
  public DockerBuildStrategyBuilder(io.fabric8.openshift.api.model.DockerBuildStrategyFluent<?> fluent,io.fabric8.openshift.api.model.DockerBuildStrategy instance) {
    this(fluent, instance, false);
  }
  public DockerBuildStrategyBuilder(io.fabric8.openshift.api.model.DockerBuildStrategyFluent<?> fluent,io.fabric8.openshift.api.model.DockerBuildStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBuildArgs(instance.getBuildArgs()); 
    fluent.withDockerfilePath(instance.getDockerfilePath()); 
    fluent.withEnv(instance.getEnv()); 
    fluent.withForcePull(instance.getForcePull()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withImageOptimizationPolicy(instance.getImageOptimizationPolicy()); 
    fluent.withNoCache(instance.getNoCache()); 
    fluent.withPullSecret(instance.getPullSecret()); 
    fluent.withVolumes(instance.getVolumes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DockerBuildStrategyBuilder(io.fabric8.openshift.api.model.DockerBuildStrategy instance) {
    this(instance,false);
  }
  public DockerBuildStrategyBuilder(io.fabric8.openshift.api.model.DockerBuildStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBuildArgs(instance.getBuildArgs()); 
    this.withDockerfilePath(instance.getDockerfilePath()); 
    this.withEnv(instance.getEnv()); 
    this.withForcePull(instance.getForcePull()); 
    this.withFrom(instance.getFrom()); 
    this.withImageOptimizationPolicy(instance.getImageOptimizationPolicy()); 
    this.withNoCache(instance.getNoCache()); 
    this.withPullSecret(instance.getPullSecret()); 
    this.withVolumes(instance.getVolumes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.DockerBuildStrategyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.DockerBuildStrategy build() {
    DockerBuildStrategy buildable = new DockerBuildStrategy(fluent.getBuildArgs(),fluent.getDockerfilePath(),fluent.getEnv(),fluent.getForcePull(),fluent.getFrom(),fluent.getImageOptimizationPolicy(),fluent.getNoCache(),fluent.getPullSecret(),fluent.getVolumes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DockerBuildStrategyBuilder that = (DockerBuildStrategyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.2.0-sources.jar: io/fabric8/openshift/api/model/DockerBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DockerBuildStrategyBuilder extends DockerBuildStrategyFluentImpl<DockerBuildStrategyBuilder> implements VisitableBuilder<DockerBuildStrategy,DockerBuildStrategyBuilder>{
  public DockerBuildStrategyBuilder() {
    this(false);
  }
  public DockerBuildStrategyBuilder(Boolean validationEnabled) {
    this(new DockerBuildStrategy(), validationEnabled);
  }
  public DockerBuildStrategyBuilder(DockerBuildStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public DockerBuildStrategyBuilder(DockerBuildStrategyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DockerBuildStrategy(), validationEnabled);
  }
  public DockerBuildStrategyBuilder(DockerBuildStrategyFluent<?> fluent,DockerBuildStrategy instance) {
    this(fluent, instance, false);
  }
  public DockerBuildStrategyBuilder(DockerBuildStrategyFluent<?> fluent,DockerBuildStrategy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBuildArgs(instance.getBuildArgs()); 
    fluent.withDockerfilePath(instance.getDockerfilePath()); 
    fluent.withEnv(instance.getEnv()); 
    fluent.withForcePull(instance.getForcePull()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withImageOptimizationPolicy(instance.getImageOptimizationPolicy()); 
    fluent.withNoCache(instance.getNoCache()); 
    fluent.withPullSecret(instance.getPullSecret()); 
    fluent.withVolumes(instance.getVolumes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DockerBuildStrategyBuilder(DockerBuildStrategy instance) {
    this(instance,false);
  }
  public DockerBuildStrategyBuilder(DockerBuildStrategy instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBuildArgs(instance.getBuildArgs()); 
    this.withDockerfilePath(instance.getDockerfilePath()); 
    this.withEnv(instance.getEnv()); 
    this.withForcePull(instance.getForcePull()); 
    this.withFrom(instance.getFrom()); 
    this.withImageOptimizationPolicy(instance.getImageOptimizationPolicy()); 
    this.withNoCache(instance.getNoCache()); 
    this.withPullSecret(instance.getPullSecret()); 
    this.withVolumes(instance.getVolumes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DockerBuildStrategyFluent<?> fluent;
  Boolean validationEnabled;
  public DockerBuildStrategy build() {
    DockerBuildStrategy buildable = new DockerBuildStrategy(fluent.getBuildArgs(),fluent.getDockerfilePath(),fluent.getEnv(),fluent.getForcePull(),fluent.getFrom(),fluent.getImageOptimizationPolicy(),fluent.getNoCache(),fluent.getPullSecret(),fluent.getVolumes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
